summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyselector.h')
-rw-r--r--kmymoney2/widgets/kmymoneyselector.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/widgets/kmymoneyselector.h b/kmymoney2/widgets/kmymoneyselector.h
index a0facf0..ad0d87b 100644
--- a/kmymoney2/widgets/kmymoneyselector.h
+++ b/kmymoney2/widgets/kmymoneyselector.h
@@ -55,7 +55,7 @@ class KMyMoneySelector : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneySelector(TQWidget *tqparent=0, const char *name=0, TQWidget::WFlags flags = 0);
+ KMyMoneySelector(TQWidget *parent=0, const char *name=0, TQWidget::WFlags flags = 0);
virtual ~KMyMoneySelector();
/**
@@ -206,20 +206,20 @@ public:
*
* @note The new item will be the first one in the selection
*
* @param tqparent pointer to tqparent item
* @param name the displayed name
* @param key String to be used for completion. If empty defaults to @a name
* @param id the id used to identify the objects
*
* @return pointer to newly created object
*/
- TQListViewItem* newItem(TQListViewItem* tqparent, const TQString& name, const TQString& key, const TQString& id);
+ TQListViewItem* newItem(TQListViewItem* parent, const TQString& name, const TQString& key, const TQString& id);
/**
* This method creates a new selectable object depending on the
* selection mode. This is either a KListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode.
* In contrast to the above method, the tqparent is always the view.
*
* @note The new item will be the first one in the selection
*
@@ -206,20 +206,20 @@ public:
* @note The new item will be the first one in the selection
*
- * @param tqparent pointer to tqparent item
+ * @param parent pointer to parent item
* @param name the displayed name
* @param key String to be used for completion. If empty defaults to @a name
@@ -206,20 +206,20 @@ public:
* selection mode. This is either a KListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode.
- * In contrast to the above method, the tqparent is always the view.
+ * In contrast to the above method, the parent is always the view.
*
* @note The new item will be the first one in the selection